@@ -322,11 +322,12 @@ class FroxlorInstall
 		$userdata .= "?>";
 		
 		// test if we can store the userdata.inc.php in ../lib
-		if ($fp = @fopen(dirname(dirname(dirname(__FILE__))) . '/lib/userdata.inc.php', 'w')) {
+		$userdata_file = dirname(dirname(dirname(__FILE__))) . '/lib/userdata.inc.php';
+		if ($fp = @fopen($userdata_file, 'w')) {
 			$result = @fputs($fp, $userdata, strlen($userdata));
 			@fclose($fp);
 			$content .= $this->_status_message('green', 'OK');
-			chmod('../lib/userdata.inc.php', 0440);
+			chmod($userdata_file, 0440);
 		} elseif ($fp = @fopen('/tmp/userdata.inc.php', 'w')) {
 			$result = @fputs($fp, $userdata, strlen($userdata));
 			@fclose($fp);
@@ -963,83 +964,39 @@ class FroxlorInstall
 		} else {
 			$content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
 		}
-		
+
+		// check for session-extension
+		$this->_requirementCheckFor($content, $_die, 'session', false, 'phpsession');
+
+		// check for ctype-extension
+		$this->_requirementCheckFor($content, $_die, 'ctype', false, 'phpctype');
+
+		// check for SimpleXML-extension
+		$this->_requirementCheckFor($content, $_die, 'simplexml', false, 'phpsimplexml');
+
 		// check for xml-extension
-		$content .= $this->_status_message('begin', $this->_lng['requirements']['phpxml']);
-		
-		if (! extension_loaded('xml')) {
-			$content .= $this->_status_message('red', $this->_lng['requirements']['notinstalled']);
-			$_die = true;
-		} else {
-			$content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
-		}
+		$this->_requirementCheckFor($content, $_die, 'xml', false, 'phpxml');
 		
 		// check for filter-extension
-		$content .= $this->_status_message('begin', $this->_lng['requirements']['phpfilter']);
-		
-		if (! extension_loaded('filter')) {
-			$content .= $this->_status_message('red', $this->_lng['requirements']['notinstalled']);
-			$_die = true;
-		} else {
-			$content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
-		}
+		$this->_requirementCheckFor($content, $_die, 'filter', false, 'phpfilter');
 		
 		// check for posix-extension
-		$content .= $this->_status_message('begin', $this->_lng['requirements']['phpposix']);
-		
-		if (! extension_loaded('posix')) {
-			$content .= $this->_status_message('red', $this->_lng['requirements']['notinstalled']);
-			$_die = true;
-		} else {
-			$content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
-		}
-		
-		// check for bstring-extension
-		$content .= $this->_status_message('begin', $this->_lng['requirements']['phpmbstring']);
-		
-		if (! extension_loaded('mbstring')) {
-			$content .= $this->_status_message('red', $this->_lng['requirements']['notinstalled']);
-			$_die = true;
-		} else {
-			$content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
-		}
+		$this->_requirementCheckFor($content, $_die, 'posix', false, 'phpposix');
+
+		// check for mbstring-extension
+		$this->_requirementCheckFor($content, $_die, 'mbstring', false, 'phpmbstring');
 		
 		// check for curl extension
-		$content .= $this->_status_message('begin', $this->_lng['requirements']['phpcurl']);
-		
-		if (! extension_loaded('curl')) {
-			$content .= $this->_status_message('red', $this->_lng['requirements']['notinstalled']);
-			$_die = true;
-		} else {
-			$content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
-		}
-		
-		// check for bcmath extension
-		$content .= $this->_status_message('begin', $this->_lng['requirements']['phpbcmath']);
-		
-		if (! extension_loaded('bcmath')) {
-			$content .= $this->_status_message('orange', $this->_lng['requirements']['notinstalled'] . "<br />" . $this->_lng['requirements']['bcmathdescription']);
-		} else {
-			$content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
-		}
-		
-		// check for zip extension
-		$content .= $this->_status_message('begin', $this->_lng['requirements']['phpzip']);
-		
-		if (! extension_loaded('zip')) {
-			$content .= $this->_status_message('orange', $this->_lng['requirements']['notinstalled'] . "<br />" . $this->_lng['requirements']['zipdescription']);
-		} else {
-			$content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
-		}
+		$this->_requirementCheckFor($content, $_die, 'curl', false, 'phpcurl');
 
 		// check for json extension
-		$content .= $this->_status_message('begin', $this->_lng['requirements']['phpjson']);
+		$this->_requirementCheckFor($content, $_die, 'json', false, 'phpjson');
+
+		// check for bcmath extension
+		$this->_requirementCheckFor($content, $_die, 'bcmath', true, 'phpbcmath', 'bcmathdescription');
 		
-		if (! extension_loaded('json')) {
-			$content .= $this->_status_message('orange', $this->_lng['requirements']['notinstalled'] . "<br />" . $this->_lng['requirements']['jsondescription']);
-		} else {
-			$content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
-		}
+		// check for zip extension
+		$this->_requirementCheckFor($content, $_die, 'zip', true, 'phpzip', 'zipdescription');
 
 		// check for open_basedir
 		$content .= $this->_status_message('begin', $this->_lng['requirements']['openbasedir']);
@@ -1049,6 +1006,16 @@ class FroxlorInstall
 		} else {
 			$content .= $this->_status_message('green', 'off');
 		}
+		
+		// check for mysqldump binary in order to backup existing database
+		$content .= $this->_status_message('begin', $this->_lng['requirements']['mysqldump']);
+
+		if (file_exists("/usr/bin/mysqldump") || file_exists("/usr/local/bin/mysqldump")) {
+			$content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
+		} else {
+			$content .= $this->_status_message('orange', $this->_lng['requirements']['notinstalled'] . "<br />" . $this->_lng['requirements']['mysqldumpmissing']);
+		}
+		
 		$content .= "</table>";
 		
 		// check if we have unrecoverable errors
@@ -1071,6 +1038,22 @@ class FroxlorInstall
 			'pagenavigation' => $navigation
 		);
 	}
+	
+	private function _requirementCheckFor(&$content, &$_die, $ext = '', $optional = false, $lng_txt = "", $lng_desc = "")
+	{
+		$content .= $this->_status_message('begin', $this->_lng['requirements'][$lng_txt]);
+		
+		if (! extension_loaded($ext)) {
+			if (!$optional) {
+				$content .= $this->_status_message('red', $this->_lng['requirements']['notinstalled']);
+				$_die = true;
+			} else {
+				$content .= $this->_status_message('orange', $this->_lng['requirements']['notinstalled'] . "<br />" . $this->_lng['requirements'][$lng_desc]);
+			}
+		} else {
+			$content .= $this->_status_message('green', $this->_lng['requirements']['installed']);
+		}
+	}
 
 	/**
 	 * send no-caching headers and set the default timezone
@@ -1139,12 +1122,24 @@ class FroxlorInstall
 			}
 		}
 		
-		$lngfile = $this->_basepath . '/install/lng/' . $this->_activelng . '.lng.php';
+		// require english base language as fallback
+		$lngfile = $this->_basepath . '/install/lng/' . $standardlanguage . '.lng.php';
 		if (file_exists($lngfile)) {
 			// includes file /lng/$language.lng.php if it exists
 			require $lngfile;
 			$this->_lng = $lng;
 		}
+		
+		// require chosen language if not english
+		if ($this->_activelng != $standardlanguage)
+		{
+			$lngfile = $this->_basepath . '/install/lng/' . $this->_activelng . '.lng.php';
+			if (file_exists($lngfile)) {
+				// includes file /lng/$language.lng.php if it exists
+				require $lngfile;
+				$this->_lng = $lng;
+			}
+		}
 	}
 
 	/**
