@@ -93,6 +93,13 @@ class DomainBulkAction
 /* 16 */    'use_ssl',
 /* 17 */	'registration_date',
 /* 18 */	'ips',
+/* 19 */	'letsencrypt',
+/* 20 */	'hsts',
+/* 21 */	'hsts_sub',
+/* 22 */	'hsts_preload',
+/* 23 */	'ocsp_stapling',
+/* 24 */	'phpenabled',
+/* 25 */	'http2',
 	    /* automatically added */
 		'adminid',
         'customerid',
@@ -180,13 +187,14 @@ class DomainBulkAction
         }
         
         // preapre insert statement as it is used a few times
+        // leave out aliasdomain for now, cause empty = NULL value which cannot be
+        // added this easily using prepared statements
         $this->_ins_stmt = Database::prepare("
 			INSERT INTO `" . TABLE_PANEL_DOMAINS . "` SET
 				`domain` = :domain,
 				`adminid` = :adminid,
 				`customerid` = :customerid,
 				`documentroot` = :documentroot,
-                `aliasdomain` = :aliasdomain,
 				`isbinddomain` = :isbinddomain,
 				`isemaildomain` = :isemaildomain,
 				`email_only` = :email_only,
@@ -200,7 +208,14 @@ class DomainBulkAction
 				`specialsettings` = :specialsettings,
 				`ssl_redirect` = :ssl_redirect,
 				`registration_date` = :registration_date,
-				`add_date` = :add_date
+				`add_date` = :add_date,
+				`letsencrypt` = :letsencrypt,
+				`hsts` = :hsts,
+				`hsts_sub` = :hsts_sub,
+				`hsts_preload` = :hsts_preload,
+				`ocsp_stapling` = :ocsp_stapling,
+				`phpenabled` = :phpenabled,
+				`http2` = :http2
 		");
         
         // prepare insert statement for ip/port <> domain
@@ -293,6 +308,7 @@ class DomainBulkAction
         }
         
         // check for alias-domain
+        $hasAlias = false;
         if (! empty($domain_data['aliasdomain'])) {
             // format
             $domain_data['aliasdomain'] = $idna_convert->encode(preg_replace(array(
@@ -301,7 +317,7 @@ class DomainBulkAction
             ), '', $domain_data['aliasdomain']));
             // validate alias-domain
             if (! validateDomain($domain_data['aliasdomain'])) {
-                // invalid-domain lol - skip to be sure we dont add anything weird
+                // invalid-domain lol - skip to be sure we don't add anything weird
                 return false;
             }
             // does the domain we want to be an alias of exists?
@@ -311,6 +327,7 @@ class DomainBulkAction
                 // - we'd better skip
                 return false;
             }
+            $hasAlias = $domain_data['aliasdomain'];
         }
         
         // check for use_ssl and ssl_redirect
@@ -335,6 +352,38 @@ class DomainBulkAction
             $domain_data['ssl_redirect'] = 0;
         }
         
+        // only check for letsencrypt, hsts and oscp-stapling if ssl is enabled
+        if ($domain_data['use_ssl'] == 1) {
+			//lets encrypt
+			if ($domain_data['letsencrypt'] != 1 || $domain_data['iswildcarddomain'] == 1) {
+				$domain_data['letsencrypt'] = 0;
+			}
+		} else {
+			$domain_data['letsencrypt'] = 0;
+		}
+
+		// hsts
+		if ($domain_data['hsts'] != 1) {
+			$domain_data['hsts'] = 0;
+		}
+		if ($domain_data['hsts_sub'] != 1) {
+			$domain_data['hsts_sub'] = 0;
+		}
+		if ($domain_data['hsts_preload'] != 1) {
+			$domain_data['hsts_preload'] = 0;
+		}
+		if ($domain_data['ocsp_stapling'] != 1) {
+			$domain_data['ocsp_stapling'] = 0;
+		}
+
+		if ($domain_data['phpenabled'] != 1) {
+			$domain_data['phpenabled'] = 0;
+		}
+
+		if ($domain_data['http2'] != 1) {
+			$domain_data['http2'] = 0;
+		}
+
         // add to known domains
         $this->_knownDomains[] = $domain_data['domain'];
         
@@ -409,20 +458,28 @@ class DomainBulkAction
         // write back iplist
         $iplist = implode(",", $result_iplist);
         
-        // dont need that for the domain-insert-statement
+        // don't need that for the domain-insert-statement
         unset($domain_data['ips']);
         
         // remember use_ssl value
         $use_ssl = (bool)$domain_data['use_ssl'];
-        // dont need that for the domain-insert-statement
+        // don't need that for the domain-insert-statement
         unset($domain_data['use_ssl']);
-        
+        // don't need alias
+        unset($domain_data['aliasdomain']);
+
         // finally ADD the domain to panel_domains
         Database::pexecute($this->_ins_stmt, $domain_data);
         
         // get the newly inserted domain-id
         $domain_id = Database::lastInsertId();
         
+        // add alias if any
+        if ($hasAlias != false) {
+			$alias_stmt = Database::prepare("UPDATE `".TABLE_PANEL_DOMAINS."` SET `aliasdomain` = :aliasdomain WHERE `id` = :did");
+			Database::pexecute($alias_stmt, array('aliasdomain' => $hasAlias, 'did' => $domain_id));
+        }
+
         // insert domain <-> ip/port reference
         if (empty($iplist)) {
             $iplist = Settings::Get('system.ipaddress');
@@ -480,7 +537,7 @@ class DomainBulkAction
                 $tmp_arr = explode($separator, $line);
                 $data_arr = array();
                 foreach ($tmp_arr as $idx => $data) {
-                    // dont include more fields that the ones we use
+                    // don't include more fields than the ones we use
                     if ($idx > (count($this->_required_fields) - 4)) // off-by-one + 3 auto-values
                         break;
                     $data_arr[$this->_required_fields[$idx]] = $data;
