@@ -163,7 +163,7 @@ return array(
 						)
 					),
 					'notryfiles' => array(
-						'visible' => (Settings('system.webserver') == 'nginx' && $userinfo['change_serversettings'] == '1'),
+						'visible' => (Settings::Get('system.webserver') == 'nginx' && $userinfo['change_serversettings'] == '1'),
 						'label' => $lng['admin']['notryfiles']['title'],
 						'desc' => $lng['admin']['notryfiles']['description'],
 						'type' => 'checkbox',
