@@ -94,6 +94,12 @@ class Autoloader {
 				dirname(dirname(__FILE__)) . '/install/',
 		);
 
+		if (substr($class, 0, 15) == "Mso\IdnaConvert") {
+			$class = substr($class, 16);
+			include_once __DIR__.'/classes/idna/ext/'.$class.'.php';
+			return true;
+		}
+
 		// now iterate through the paths
 		foreach ($paths as $path) {
 			// valid directory?
