@@ -26,13 +26,13 @@
  */
 function correctErrorDocument($errdoc = null) {
 
-	global $settings, $idna_convert;
+	global $idna_convert;
 
 	if ($errdoc !== null && $errdoc != '') {
 		// not a URL
 		if ((strtoupper(substr($errdoc, 0, 5)) != 'HTTP:'
 				&& strtoupper(substr($errdoc, 0, 6)) != 'HTTPS:')
-				|| !validateUrl($idna_convert->encode($errdoc))
+				|| !validateUrl($errdoc)
 		) {
 			// a file
 			if (substr($errdoc, 0, 1) != '"') {
@@ -45,15 +45,14 @@ function correctErrorDocument($errdoc = null) {
 			// a string (check for ending ")
 			else {
 				// string won't work for lighty
-				if ($settings['system']['webserver'] == 'lighttpd') {
+				if (Settings::Get('system.webserver') == 'lighttpd') {
 					standard_error('stringerrordocumentnotvalidforlighty');
-
 				} elseif(substr($errdoc, -1) != '"') {
 					$errdoc .= '"';
 				}
 			}
 		} else {
-			if ($settings['system']['webserver'] == 'lighttpd') {
+			if (Settings::Get('system.webserver') == 'lighttpd') {
 				standard_error('urlerrordocumentnotvalidforlighty');
 			}
 		}
