@@ -15,23 +15,24 @@
  *
  */
 
-/*
- * returns true or false whether a 
- * given domain id is the std-subdomain
- * of a customer
+/**
+ * returns true or false whether a given domain id
+ * is the std-subdomain of a customer
  *
- * @param	int		domain-id
+ * @param int domain-id
  *
- * @return	boolean
+ * @return boolean
  */
-function isCustomerStdSubdomain($did = 0)
-{
-	global $db;
+function isCustomerStdSubdomain($did = 0) {
 
-	if($did > 0)
-	{
-		$result = $db->query_first("SELECT `customerid` FROM `".TABLE_PANEL_CUSTOMERS."` WHERE `standardsubdomain` = '".(int)$did."'");
-		if(is_array($result) 
+	if ($did > 0) {
+		$result_stmt = Database::prepare("
+			SELECT `customerid` FROM `".TABLE_PANEL_CUSTOMERS."`
+			WHERE `standardsubdomain` = :did
+		");
+		$result = Database::pexecute_first($result_stmt, array('did' => $did));
+
+		if (is_array($result)
 			&& isset($result['customerid'])
 			&& $result['customerid'] > 0
 		) {
