@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id$
+ *
  */
 
 /**
@@ -29,7 +29,7 @@
  * @author Florian Lippert <flo@syscp.org>
  */
 
-function makeoption($title, $value, $selvalue = NULL, $title_trusted = false, $value_trusted = false)
+function makeoption($title, $value, $selvalue = NULL, $title_trusted = false, $value_trusted = false, $id = NULL, $disabled = false)
 {
 	if($selvalue !== NULL
 	   && ((is_array($selvalue) && in_array($value, $selvalue)) || $value == $selvalue))
@@ -40,6 +40,10 @@ function makeoption($title, $value, $selvalue = NULL, $title_trusted = false, $v
 	{
 		$selected = '';
 	}
+	
+	if ($disabled) {
+		$selected .= ' disabled="disabled"';
+	}
 
 	if(!$title_trusted)
 	{
@@ -51,6 +55,11 @@ function makeoption($title, $value, $selvalue = NULL, $title_trusted = false, $v
 		$value = htmlspecialchars($value);
 	}
 
-	$option = '<option value="' . $value . '" ' . $selected . ' >' . $title . '</option>';
+	$id_str = ' ';
+	if($id !== NULL) {
+		$id_str = 'id="' . $id . '"';
+	}
+
+	$option = '<option value="' . $value . '" ' . $id_str . $selected . ' >' . $title . '</option>';
 	return $option;
 }
