@@ -14,33 +14,28 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id$
+ *
  */
 
 /**
  * Returns Array, whose elements have been checked whether thay are empty or not
  *
- * @param array The array to trim
+ * @param array $source
+ *        	The array to trim
  * @return array The trim'med array
  * @author Florian Lippert <flo@syscp.org>
  */
-
 function array_trim($source)
 {
 	$returnval = array();
-
-	if(is_array($source))
-	{
-		while(list($var, $val) = each($source))
-		{
-			if($val != ' '
-			   && $val != '')$returnval[$var] = $val;
+	if (is_array($source)) {
+		foreach ($source as $var => $val) {
+			if ($val != ' ' && $val != '') {
+				$returnval[$var] = $val;
+			}
 		}
-	}
-	else
-	{
+	} else {
 		$returnval = $source;
 	}
-
 	return $returnval;
 }
